[![Downloads](https://pepy.tech/badge/Flask-School)](https://pepy.tech/project/Flask-School)

flask extension with new-school-sdk, 一个正方教务系统的Flask扩展


本项目是基于`school-sdk`的一个`Flask`扩展，封装了常用的方法.

## 相关项目

- 新版正方教务系统: https://github.com/Farmer-chong/new-school-sdk
- 旧版正方教务系统: https://github.com/dairoot/school-api

## License

This project is licensed under the MIT License (see the
`LICENSE` file for details).
